/*
 * Redigera denna fil och spara den som userChrome.css i mappen "chrome"
 * i din profilmapp.
 */

/*
 * Denna fil kan användas till att anpassa utseendet på Mozilla Firefox.
 * Du bör använda tillägget "!important" på de regler du använder för att
 * åsidosätta standardinställningarna.
 * Du kan placera kommentarer till reglerna så här:  /* lite text om regeln här */
 */

/*
 * Ta inte bort raden @namespace -- den behövs för att filen ska fungera på rätt sätt.
 */
 
@namespace url("http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul"); /* set default namespace to XUL */


/* Några möjliga förbättringar. För att använda dessa, ta bort de "/*", "*" och "*/" som inleder varje rad. */
 
/* Ange standardstorleken på teckensnitt till 20 pt: */
 
 /*
 * * {
 *   font-size: 20pt !important
 * }
 */
 
/* Ändra storleken på menyposter till 15 pt istället för den vanliga storleken: */

 /* 
 * menupopup > * {
 *   font-size: 15pt !important
 * }
 */
 
/* Använd ett teckensnitt med fast breddsteg i Adressfältet: */
 
 /*
 * #urlbar {
 *    font-family: monospace !important;
 * }
 */

/* Ta bort "throbbern" och den irriterande animeringen: */
 
 /*
 * #throbber-box {
 *   display: none !important;
 * }
 */

/*
 * För fler exempel, se http://www.mozilla.org/unix/customizing.html
 */
 
